TimerHandle

Struct TimerHandle 

pub struct TimerHandle { /* private fields */ }
Handle to a timer 定时器句柄

Can be used to cancel the timer before it expires. The handle references the global timer wheel, which has static lifetime. 可用于在定时器到期前取消它。 句柄引用全局时间轮,全局时间轮具有静态生命周期。

Implementations

Source

impl TimerHandle

pub fn cancel(&self)

Cancel this timer 取消此定时器